@@ -39,6 +39,7 @@ use EBox::Squid::LogHelper;
 use EBox::SquidOnlyFirewall;
 use EBox::Squid::LdapUserImplementation;
 
+use EBox::DBEngineFactory;
 use EBox::Dashboard::Value;
 use EBox::Dashboard::Section;
 use EBox::Menu::Item;
@@ -59,13 +60,14 @@ use constant DGPORT => '3129';
 use constant DGDIR => '/etc/dansguardian';
 use constant DGLISTSDIR => DGDIR . '/lists';
 use constant DG_LOGROTATE_CONF => '/etc/logrotate.d/dansguardian';
+use constant CLAMD_SCANNER_CONF_FILE => DGDIR . '/contentscanners/clamdscan.conf';
 
 sub _create
 {
     my $class = shift;
     my $self  = $class->SUPER::_create(name => 'squid',
                                        domain => 'ebox-squid',
-                                       printableName => __('HTTP Proxy'),
+                                       printableName => __n('HTTP Proxy'),
                                        @_);
     $self->{logger} = EBox::logger();
     bless ($self, $class);
@@ -269,6 +271,11 @@ sub usedFiles
              'module' => 'squid',
              'reason' => __(q{Dansguardian's log rotation configuration}),
             },
+            {
+                'file' => CLAMD_SCANNER_CONF_FILE,
+                'module' => 'squid',
+             'reason' => __(q{Dansguardian's antivirus scanner configuration}),
+            },
 
            ];
 }
@@ -566,9 +573,10 @@ sub usesPort # (protocol, port, iface)
 sub restartService
 {
     my ($self, @params) = @_;
-    $self->SUPER::restartService(@params);
 
     $self->_cleanDomainFilterFiles();
+
+    $self->SUPER::restartService(@params);
 }
 
 
@@ -617,14 +625,11 @@ sub _antivirusNeeded
 
 sub notifyAntivirusEnabled
 {
-    my ($self) = @_;
-    $self->_dgNeeded() or 
+    my ($self, $enabled) = @_;
+    $self->_dgNeeded() or
         return;
 
-    if ($self->_antivirusNeeded()) {
-        $self->setAsChanged();
-    }
-
+    $self->setAsChanged();
 }
 
 sub _writeSquidConf
@@ -650,7 +655,7 @@ sub _writeSquidConf
   push @writeParam, ('notCachedDomains'=> $self->_notCachedDomains());
   push @writeParam, ('cacheDirSize'     => $cacheDirSize);
   push @writeParam, ('dn'     => $users->ldap()->dn());
-  if ($users->isMaster()) {
+  unless ($users->mode() eq 'slave') {
       push @writeParam, ('ldapport' => $users->ldap()->ldapConf()->{'port'});
   } else {
       push @writeParam, ('ldapport' => $users->ldap()->ldapConf()->{'replicaport'});
@@ -709,6 +714,17 @@ sub _writeDgConf
                        []
                       );
 
+  if ($antivirus) {
+      my $avMod = EBox::Global->modInstance('antivirus');
+      $self->writeConfFile(CLAMD_SCANNER_CONF_FILE,
+                           "squid/clamdscan.conf.mas",
+                           [
+                               clamdSocket => $avMod->localSocket(),
+                           ]
+                          );
+
+  }
+
 
   foreach my $group (@dgFilterGroups) {
       my $number = $group->{number};
@@ -967,7 +983,7 @@ sub menu
     my ($self, $root) = @_;
     my $folder = new EBox::Menu::Folder('name' => 'Squid',
                                         'text' => $self->printableName(),
-                                        'separator' => __('Gateway'),
+                                        'separator' => 'Gateway',
                                         'order' => 210);
 
     $folder->add(new EBox::Menu::Item('url' => 'Squid/Composite/General',
@@ -1031,8 +1047,7 @@ sub tableInfo
             'index' => 'squid',
             'titles' => $titles,
             'order' => \@order,
-            'tablename' => 'access',
-            'timecol' => 'timestamp',
+            'tablename' => 'squid_access',
             'filter' => ['url', 'remotehost', 'rfc931'],
             'events' => $events,
             'eventcol' => 'event',
@@ -1157,7 +1172,109 @@ sub restoreConfig
     $filterGroups->restoreConfig($dir);
 }
 
+sub report
+{
+    my ($self, $beg, $end, $options) = @_;
 
+    my $report = {};
+
+    my $db = EBox::DBEngineFactory::DBEngine();
+
+    $report->{'summarized_traffic'} = $self->runMonthlyQuery($beg, $end, {
+        'select' => 'event, SUM(bytes) AS bytes, SUM(hits) AS hits',
+        'from' => 'squid_access_report',
+        'group' => "event"
+    }, { 'key' => 'event' });
+
+    $report->{'top_domains'} = $self->runQuery($beg, $end, {
+        'select' => 'domain, SUM(bytes) AS traffic_bytes, SUM(hits) AS hits',
+        'from' => 'squid_access_report',
+        'where' => "event = 'accepted'",
+        'group' => 'domain',
+        'limit' => $options->{'max_top_domains'},
+        'order' => 'traffic_bytes DESC'
+    });
+
+    $report->{'top_blocked_domains'} = $self->runQuery($beg, $end, {
+        'select' => 'domain, SUM(hits) AS hits',
+        'from' => 'squid_access_report',
+        'where' => "event = 'denied' OR event = 'filtered'",
+        'group' => 'domain',
+        'limit' => $options->{'max_top_blocked_domains'},
+        'order' => 'hits DESC'
+    });
+
+    $report->{'top_ips'} = $self->runQuery($beg, $end, {
+        'select' => 'ip, SUM(bytes) AS traffic_bytes, SUM(hits) AS hits',
+        'from' => 'squid_access_report',
+        'where' => "event = 'accepted'",
+        'group' => 'ip',
+        'limit' => $options->{'max_top_ips'},
+        'order' => 'traffic_bytes DESC'
+    });
+
+    $report->{'top_blocked_ips'} = $self->runQuery($beg, $end, {
+        'select' => 'ip, SUM(hits) AS hits',
+        'from' => 'squid_access_report',
+        'where' => "event = 'denied' OR event = 'filtered'",
+        'group' => 'ip',
+        'limit' => $options->{'max_top_blocked_ips'},
+        'order' => 'hits DESC'
+    });
+
+    $report->{'top_users'} = $self->runQuery($beg, $end, {
+        'select' => 'username, SUM(bytes) AS traffic_bytes, SUM(hits) AS hits',
+        'from' => 'squid_access_report',
+        'where' => "event = 'accepted' AND username <> '-'",
+        'group' => 'username',
+        'limit' => $options->{'max_top_users'},
+        'order' => 'traffic_bytes DESC'
+    });
+
+    $report->{'top_blocked_users'} = $self->runQuery($beg, $end, {
+        'select' => 'username, SUM(hits) AS hits',
+        'from' => 'squid_access_report',
+        'where' => "(event = 'denied' OR event = 'filtered') AND username <> '-'",
+        'group' => 'username',
+        'limit' => $options->{'max_top_blocked_users'},
+        'order' => 'hits DESC'
+    });
+
+    $report->{'top_domains_by_user'} = $self->runCompositeQuery($beg, $end,
+    {
+        'select' => 'username, SUM(bytes) AS bytes',
+        'from' => 'squid_access_report',
+        'where' => "event = 'accepted' AND username <> '-'",
+        'group' => 'username',
+        'limit' => $options->{'max_users_top_domains_by_user'},
+        'order' => 'bytes DESC'
+    },
+    'username',
+    {
+        'select' => 'domain, SUM(bytes) AS traffic_bytes, SUM(hits) AS hits',
+        'from' => 'squid_access_report',
+        'where' => "event = 'accepted' AND username = '_username_'",
+        'group' => 'domain',
+        'limit' => $options->{'max_domains_top_domains_by_user'},
+        'order' => 'traffic_bytes DESC'
+    });
+
+    return $report;
+}
+
+sub consolidateReportQueries
+{
+    return [
+        {
+            'target_table' => 'squid_access_report',
+            'query' => {
+                'select' => 'rfc931 AS username, remotehost AS ip, domain_from_url(url) AS domain, event, SUM(bytes) AS bytes, COUNT(event) AS hits',
+                'from' => 'squid_access',
+                'group' => 'username, ip, domain, event'
+            }
+        }
+    ];
+}
 
 # LdapModule implementation
 sub _ldapModImplementation
@@ -1165,5 +1282,4 @@ sub _ldapModImplementation
     return new EBox::Squid::LdapUserImplementation();
 }
 
-
 1;
