@@ -57,14 +57,14 @@ sub new
 # Method: pageTitle
 #
 #   Overrides:
-#       
+#
 #       <EBox::Model::Composite::headTitle>
 #
 # Returns:
 #
 #
 #   undef
-sub pageTitle 
+sub pageTitle
 {
     return undef;
 }
@@ -83,8 +83,9 @@ sub _description
       my $description =
         {
          components      => [
-			     'DomainFilterSettings',
+                             'DomainFilterSettings',
                              'DomainFilter',
+                             'DomainFilterFiles',
                             ],
          layout          => 'top-bottom',
          name            => 'Domains',
