@@ -22,8 +22,8 @@
 #
 #   It subclasses <EBox::Model::DataTable>
 #
-#  
-# 
+#
+#
 
 package EBox::Squid::Model::ContentFilterThreshold;
 use base 'EBox::Model::DataForm';
@@ -34,14 +34,14 @@ use warnings;
 # eBox classes
 use EBox::Global;
 use EBox::Gettext;
-use EBox::Types::Select;
+
+use  EBox::Squid::Types::WeightedPhrasesThreshold;
 
 
-
-# eBox exceptions used 
+# eBox exceptions used
 use EBox::Exceptions::External;
 
-sub new 
+sub new
 {
     my $class = shift @_ ;
 
@@ -58,20 +58,17 @@ sub new
 # a table model description.
 #
 
-# 
+#
 sub _table
 {
-    my @tableDesc = 
-        ( 
+    my @tableDesc =
+        (
 
-         new EBox::Types::Select(
+         new  EBox::Squid::Types::WeightedPhrasesThreshold(
              fieldName => 'contentFilterThreshold',
              printableName => __('Threshold'),
              editable => 1,
-             defaultValue  => 0,
-             populate => \&_populateContentFilterThreshold ,
-             help     => _thresholdHelp(),
-             ), 
+             ),
 
 
         );
@@ -96,23 +93,7 @@ sub _table
 
 
 
-sub _populateContentFilterThreshold
-  {
-      return [
-      { value => 0, printableValue => __('Disabled'),  },
-      { value => 200, printableValue => __('Very permissive'),  },
-      { value => 160, printableValue => __('Permissive'),  },
-      { value => 120, printableValue => __('Medium'),  },
-      { value => 80, printableValue => __('Strict'),  },
-      { value => 50, printableValue => __('Very strict'),  },
-      ];
 
-  }
-
-sub _thresholdHelp
-{
-    return __('This specifies how strict the content filter is.');
-}
 
 
 
