@@ -15,5 +15,5 @@ CREATE TABLE squid_traffic (
         filtered_size BIGINT DEFAULT 0
 );
 
-CREATE INDEX date on squid_traffic(timestamp);
+CREATE INDEX squid_traffic_date_i on squid_traffic(timestamp);
 
